local _logger = require("logging")

local SETTING_NAME = "set_password"

local function CreateOrUpdateSetting(device_id, setting_id, value)

    value = value or ""

    if #value & 1 == 1 then
        _logger.error("Invalid password")
        return
    end

    if setting_id then
        local _core = require("core")
        _logger.debug("Update setting value: " .. SETTING_NAME .. " = " .. tostring(value))
        _core.set_setting_value(setting_id, value, "synced")
        return
    end

    local _setting_utils = require("HUB:wol/scripts/modules/setting_utils")

    local setting = {
        label = {
            text = "Password"
        },
        description = {
            text = "e.g. 001122AABBFF"
        },
        value_type = "string",
        value = value,
        status = "synced",
        has_setter = true,
        info = {
            name = SETTING_NAME
        }
    }

    _setting_utils.CreateSetting(device_id, SETTING_NAME, setting)

end

local params = ... or {}

if not params.device_id then
    _logger.error("Missing device_id. Cannot continue.")

    return
end

CreateOrUpdateSetting(params.device_id, params.setting_id, params.value)
